@@ -1,3 +1,3 @@
 # Update namespace to allow easier imports such as "from dokusu import Sudoku"
-from . import dokusu
-from .dokusu import *
+from . import core
+from .core import *
